@@ -1,6 +1,7 @@
 from __future__ import print_function
 import os
 import sys
+import subprocess
 
 
 def colorize(sheet_content):
@@ -30,20 +31,31 @@ def die(message):
 
 def editor():
     """ Determines the user's preferred editor """
-    if 'EDITOR' not in os.environ:
+
+    # determine which editor to use
+    editor = os.environ.get('CHEAT_EDITOR') \
+        or os.environ.get('VISUAL')         \
+        or os.environ.get('EDITOR')         \
+        or False
+
+    # assert that the editor is set
+    if editor == False:
         die(
-            'In order to create/edit a cheatsheet you must set your EDITOR '
-            'environment variable to your editor\'s path.'
+            'You must set a CHEAT_EDITOR, VISUAL, or EDITOR environment '
+            'variable in order to create/edit a cheatsheet.'
         )
 
-    elif os.environ['EDITOR'] == "":
-        die(
-            'Your EDITOR environment variable is set to an empty string. It must '
-            'be set to your editor\'s path.'
-        )
+    return editor
+
+
+def open_with_editor(filepath):
+    """ Open `filepath` using the EDITOR specified by the environment variables """
+    editor_cmd = editor().split()
+    try:
+        subprocess.call(editor_cmd + [filepath])
+    except OSError:
+        die('Could not launch ' + editor())
 
-    else:
-        return os.environ['EDITOR']
 
 def warn(message):
     """ Prints a message to stderr """
